# How to contribute?

[![Open in Visual Studio Code](https://open.vscode.dev/badges/open-in-vscode.svg)](https://open.vscode.dev/ComPWA/ampform)
[![GitPod](https://img.shields.io/badge/Gitpod-ready--to--code-blue?logo=gitpod)](https://gitpod.io/#https://github.com/ComPWA/ampform)

This package is part of the [ComPWA Organization](https://github.com/ComPWA).
For more information about how to contribute to the packages, go to
[pwa.rtfd.io/develop.html](https://pwa.readthedocs.io/develop.html)!
